@@ -329,7 +329,7 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, env = .GlobalEnv, ..
 get.X.class <- function(X) {
     if (is_not_null(X[["imp"]])) {
         if (is_not_null(X[["treat.list"]])) stop("Multiply imputed data is not yet supported with longitudinal treatments.", call. = FALSE)
-        else if (is_(X[["treat"]], c("factor", "character"))) stop("Multiply imputed data is not yet supported with multinomial treatments.", call. = FALSE)
+        else if (is_(X[["treat"]], c("factor", "character")) && !is_binary(X[["treat"]])) stop("Multiply imputed data is not yet supported with multinomial treatments.", call. = FALSE)
         else X.class <- "imp"
     }
     else if (is_not_null(X[["treat.list"]])) X.class <- "msm"
@@ -341,9 +341,9 @@ get.X.class <- function(X) {
     return(X.class)
 }
 probably.a.bug <- function() {
-    fun <- deparse(sys.call(-1))
-    stop(paste0("An error was produced and is likely a bug. Please let the maintainer know a bug was produced by the function ",
-                fun, "."), call. = FALSE)
+    fun <- paste(deparse(sys.call(-1)), collapse = "\n")
+    stop(paste0("An error was produced and is likely a bug. Please let the maintainer know a bug was produced by the function\n",
+                fun), call. = FALSE)
 }
 subset_X <- function(X, subset) {
     n <- length(subset)
@@ -381,7 +381,7 @@ int.poly.f <- function(mat, ex=NULL, int=FALSE, poly=1, center = FALSE, sep, co.
     else d <- mat
     binary.vars <- apply(d, 2, is_binary)
     if (center) {
-        d[,!binary.vars] <- scale(d[, !binary.vars, drop = FALSE], center = TRUE, scale = FALSE)
+        d[,!binary.vars] <- center(d[, !binary.vars, drop = FALSE])
     }
     nd <- NCOL(d)
     nrd <- NROW(d)
@@ -421,13 +421,12 @@ binarize <- function(variable) {
     newvar[nas] <- NA_real_
     return(newvar)
 }
-get.C <- function(covs, int = FALSE, addl = NULL, distance = NULL, cluster = NULL, ...) {
+get.C <- function(covs, int = FALSE, poly = 1, addl = NULL, distance = NULL, cluster = NULL, ...) {
     #gets C data.frame, which contains all variables for which balance is to be assessed. Used in balance.table.
     A <- list(...)
     if (is_null(A[["int_sep"]])) A[["int_sep"]] <- getOption("cobalt_int_sep", default = " * ")
     if (is_null(A[["factor_sep"]])) A[["factor_sep"]] <- getOption("cobalt_factor_sep", default = "_")
-    if (is_null(A[["center"]]) || A[["center"]] %nin% c(TRUE, FALSE)) A[["center"]] <- FALSE
-    if (is_not_null(A[["poly"]])) poly <- A[["poly"]] else poly <- int
+    if (is_null(A[["center"]]) || A[["center"]] %nin% c(TRUE, FALSE)) A[["center"]] <- getOption("cobalt_center", default = FALSE)
     
     C <- covs
     if (!is.null(addl)) {
@@ -502,14 +501,22 @@ get.C <- function(covs, int = FALSE, addl = NULL, distance = NULL, cluster = NUL
     C <- C[!vapply(C, all_the_same, logical(1L))]
     C <- as.matrix(C)
     
-    #Process int
+    #Process int and poly
     if (length(int) != 1L || !is.finite(int) || !(is.logical(int) || is.numeric(int))) {
         stop("int must be TRUE, FALSE, or a numeric value of length 1.", call. = FALSE)
     }
-    int <- as.integer(round(int))
-    if (int < 0) {
+    if (int < 0 || !check_if_zero(abs(int - round(int)))) {
         stop("int must be TRUE, FALSE, or a numeric (integer) value greater than 1.", call. = FALSE)
     }
+    int <- as.integer(round(int))
+    
+    if (length(poly) != 1L || !is.finite(poly) || !is.numeric(poly)) {
+        stop("poly must be a numeric value of length 1.", call. = FALSE)
+    }
+    if (poly < 0 || !check_if_zero(abs(poly - round(poly)))) {
+        stop("poly must be a numeric (integer) value greater than 1.", call. = FALSE)
+    }
+    poly <- as.integer(round(poly))
     
     if (int || poly) {
         if (int) { 
@@ -521,13 +528,11 @@ get.C <- function(covs, int = FALSE, addl = NULL, distance = NULL, cluster = NUL
                 else nsep <- nsep + 1
             }
             
-            if (as.numeric(int) %in% c(1, 2)) {
-                if (!poly) poly <- 2
-            }
-            else poly <- int
+            if (poly < int) poly <- int
             
             int <- TRUE
         }
+        
         new <- int.poly.f(C, int = int, poly = poly, center = A[["center"]], sep = rep(A[["int_sep"]], nsep), co.names = co.names)
         C <- cbind(C, new)
         co.names <- c(co.names, attr(new, "co.names"))
@@ -737,6 +742,16 @@ col.std.diff <- function(mat, treat, weights, subclass = NULL, which.sub = NULL,
     w <- weights*s.weights
     sw <- s.weights
     
+    #Check continuous and binary
+    if (missing(continuous) || is_null(continuous)) {
+        continuous <- match_arg(getOption("cobalt_continuous", "std"), c("std", "raw"))
+    }
+    else continuous <- match_arg(continuous, c("std", "raw"))
+    if (missing(binary) || is_null(binary)) {
+        binary <- match_arg(getOption("cobalt_binary", "raw"), c("raw", "std"))
+    }
+    else binary <- match_arg(binary, c("raw", "std"))
+    
     no.sub <- is_null(which.sub)
     if (no.sub) ss <- sw > 0
     else {
@@ -949,6 +964,7 @@ samplesize <- function(treat, weights = NULL, subclass = NULL, s.weights = NULL,
     return(nn)
 }
 samplesize.across.clusters <- function(samplesize.list) {
+    samplesize.list <- clear_null(samplesize.list)
     obs <- Reduce("+", samplesize.list)
     attr(obs, "tag") <- paste0("Total ", tolower(attr(samplesize.list[[1]], "tag")), " across clusters")
     return(obs)
@@ -1221,6 +1237,7 @@ balance.table.across.subclass <- function(balance.table, balance.table.subclass.
 }
 balance.table.cluster.summary <- function(balance.table.clusters.list, weight.names = NULL, no.adj = FALSE, abs = FALSE, quick = FALSE, types = NULL) {
     
+    balance.table.clusters.list <- clear_null(balance.table.clusters.list)
     cont.treat <- "Corr.Un" %in% unique(do.call("c", lapply(balance.table.clusters.list, names)))
     if (no.adj) weight.names <- "Adj"
     
@@ -1274,7 +1291,7 @@ samplesize.cont <- function(treat, weights = NULL, subclass = NULL, s.weights =
     #Computes sample size info. for unadjusted and adjusted samples.
     # method is what method the weights are to be used for. 
     # method="subclassification" is for subclass sample sizes only.
-    #method <- match.arg(method)
+    #method <- match_arg(method)
     if (nlevels(cluster) > 0 && is_not_null(which.cluster)) in.cluster <- cluster == which.cluster
     else in.cluster <- rep(TRUE, length(treat))
     if (is_null(discarded)) discarded <- rep(0, length(treat))
@@ -1511,6 +1528,7 @@ balance.table.imp.summary <- function(bal.tab.imp.list, weight.names = NULL, no.
         bal.tab.imp.list <- lapply(bal.tab.imp.list, function(x) x[["Balance"]])}
     cont.treat <- "Corr.Un" %in% unique(do.call("c", lapply(bal.tab.imp.list, names)))
     if (length(weight.names) <= 1) weight.names <- "Adj"
+    bal.tab.imp.list <- clear_null(bal.tab.imp.list)
     
     Brownames <- unique(do.call("c", lapply(bal.tab.imp.list, rownames)))
     #imp.functions <- c("Min", "Mean", "Median", "Max")
@@ -1521,9 +1539,9 @@ balance.table.imp.summary <- function(bal.tab.imp.list, weight.names = NULL, no.
     names(B) <- Bcolnames
     
     if (is_not_null(types)) B[["Type"]] <- types
-    else B[["Type"]] <- unlist(lapply(Brownames, function(x) {u <- unique(vapply(bal.tab.imp.list, function(y) y[[x, "Type"]], character(1))); return(u[!is.na(u)])}), use.names = FALSE)
+    else B[["Type"]] <- unlist(lapply(Brownames, function(x) {u <- unique(sapply(bal.tab.imp.list, function(y) y[[x, "Type"]])); return(u[!is.na(u)])}), use.names = FALSE)
     
-    abs0 <- function(x) {if (abs) abs(x) else (x)}
+    abs0 <- function(x) {if (is_null(x)) NA_real_ else if (abs) abs(x) else (x)}
     funs <- structure(vector("list", length(imp.functions)), names = imp.functions)
     for (Fun in imp.functions) {
         funs[[Fun]] <- function(x, ...) {
@@ -1594,6 +1612,7 @@ balance.table.clust.imp.summary <- function(summary.tables, weight.names = NULL,
 }
 samplesize.across.imps <- function(obs.list) {
     #obs.list <- lapply(bal.tab.imp.list, function(x) x[["Observations"]])
+    obs.list <- clear_null(obs.list)
     
     obs <- Reduce("+", obs.list)/length(obs.list)
     attr(obs, "tag") <- paste0("Average ", tolower(attr(obs.list[[1]], "tag")), " across imputations")
@@ -1605,6 +1624,7 @@ balance.table.multi.summary <- function(bal.tab.multi.list, weight.names = NULL,
     if ("bal.tab" %in% unique(do.call("c", lapply(bal.tab.multi.list, class)))) {
         bal.tab.multi.list <- lapply(bal.tab.multi.list, function(x) x[["Balance"]])}
     if (length(weight.names) <= 1) weight.names <- "Adj"
+    bal.tab.multi.list <- clear_null(bal.tab.multi.list)
     
     Brownames <- unique(do.call("c", lapply(bal.tab.multi.list, rownames)))
     Bcolnames <- c("Type", expand.grid_string(c("Max.Diff", "M.Threshold", "Max.V.Ratio", "V.Threshold", "Max.KS", "KS.Threshold"), 
@@ -1668,6 +1688,7 @@ balance.table.multi.summary <- function(bal.tab.multi.list, weight.names = NULL,
 samplesize.multi <- function(bal.tab.multi.list, treat.names, focal) {
     if (is_not_null(focal)) which <- c(treat.names[treat.names != focal], focal)
     else which <- treat.names
+    bal.tab.multi.list <- clear_null(bal.tab.multi.list)
     obs <- do.call("cbind", unname(lapply(bal.tab.multi.list, function(x) x[["Observations"]])))[, which]
     attr(obs, "tag") <- attr(bal.tab.multi.list[[1]][["Observations"]], "tag")
     attr(obs, "ss.type") <- attr(bal.tab.multi.list[[1]][["Observations"]], "ss.type")
@@ -1855,8 +1876,7 @@ round_df_char <- function(df, digits, pad = "0", na_vals = "") {
     nums <- vapply(df, is.numeric, logical(1))
     o.negs <- sapply(1:NCOL(df), function(x) if (nums[x]) df[[x]] < 0 else rep(FALSE, length(df[[x]])))
     df[nums] <- round(df[nums], digits = digits)
-    #print(nas)
-    #print(infs); stop()
+    
     df[nas | infs] <- ""
     
     df <- as.data.frame(lapply(df, format, scientific = FALSE, justify = "none"), stringsAsFactors = FALSE)
@@ -1897,6 +1917,31 @@ print.data.frame_ <- function(x, ...) {
     }
 }
 
+#set.cobalt.options
+acceptable.options <- function() {
+    TF <- c(TRUE, FALSE)
+    return(list(un = TF,
+                continuous = c("raw", "std"),
+                binary = c("raw", "std"),
+                imbalanced.only = TF,
+                disp.means = TF,
+                disp.sds = TF,
+                disp.v.ratio = TF,
+                disp.ks = TF,
+                disp.subclass = TF,
+                disp.bal.tab = TF,
+                cluster.summary = TF,
+                cluster.fun = c("min", "mean", "max"),
+                imp.summary = TF,
+                imp.fun = c("min", "mean", "max"),
+                multi.summary = TF,
+                msm.summary = TF,
+                target.summary = TF,
+                int_sep = " * ",
+                factor_sep = "_",
+                center = TF))
+}
+
 #To pass CRAN checks:
 utils::globalVariables(c("distance", "addl", "addl.list", "distance.list",
                          "quick", "treat", "Sample", "min.stat",
